@@ -31,23 +31,26 @@ RadioButtonItemDelegate::RadioButtonItemDelegate(QObject *p)
 
 void RadioButtonItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    if (index.data(RadioButtonTreeView::IsRadioRole).canConvert<bool>() && index.data(RadioButtonTreeView::IsRadioRole).value<bool>()) {
+    if (index.data(RadioButtonTreeView::IsRadioRole).canConvert<bool>() && index.data(RadioButtonTreeView::IsRadioRole).toBool()) {
         /// determine size and spacing of radio buttons in current style
-        int radioButtonWidth = QApplication::style()->pixelMetric(QStyle::PM_ExclusiveIndicatorWidth, &option);
-        int spacing = QApplication::style()->pixelMetric(QStyle::PM_RadioButtonLabelSpacing, &option);
+        const int radioButtonWidth = QApplication::style()->pixelMetric(QStyle::PM_ExclusiveIndicatorWidth, &option);
+        const int radioButtonHeight = QApplication::style()->pixelMetric(QStyle::PM_ExclusiveIndicatorHeight, &option);
+        const int spacing = QApplication::style()->pixelMetric(QStyle::PM_RadioButtonLabelSpacing, &option);
 
         /// draw default appearance (text, highlighting) shifted to the left
         QStyleOptionViewItem myOption = option;
-        int left = myOption.rect.left();
+        const int left = myOption.rect.left();
         myOption.rect.setLeft(left + spacing * 3 / 2 + radioButtonWidth);
         QStyledItemDelegate::paint(painter, myOption, index);
 
         /// draw radio button in the open space
         myOption.rect.setLeft(left + spacing / 2);
         myOption.rect.setWidth(radioButtonWidth);
+        myOption.rect.setTop(option.rect.top() + (option.rect.height() - radioButtonHeight) / 2);
+        myOption.rect.setHeight(radioButtonHeight);
         if (index.data(RadioButtonTreeView::RadioSelectedRole).canConvert<bool>()) {
             /// change radio button's visual appearance if selected or not
-            bool radioButtonSelected = index.data(RadioButtonTreeView::RadioSelectedRole).value<bool>();
+            bool radioButtonSelected = index.data(RadioButtonTreeView::RadioSelectedRole).toBool();
             myOption.state |= radioButtonSelected ? QStyle::State_On : QStyle::State_Off;
         }
         QApplication::style()->drawPrimitive(QStyle::PE_IndicatorRadioButton, &myOption, painter);
@@ -58,7 +61,7 @@ void RadioButtonItemDelegate::paint(QPainter *painter, const QStyleOptionViewIte
 QSize RadioButtonItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QSize s = QStyledItemDelegate::sizeHint(option, index);
-    if (index.data(RadioButtonTreeView::IsRadioRole).value<bool>()) {
+    if (index.data(RadioButtonTreeView::IsRadioRole).toBool()) {
         /// determine size of radio buttons in current style
         int radioButtonHeight = QApplication::style()->pixelMetric(QStyle::PM_ExclusiveIndicatorHeight, &option);
         /// ensure that line is tall enough to draw radio button
@@ -78,7 +81,7 @@ RadioButtonTreeView::RadioButtonTreeView(QWidget *parent)
 void RadioButtonTreeView::mouseReleaseEvent(QMouseEvent *event)
 {
     QModelIndex index = indexAt(event->pos());
-    if (index.data(IsRadioRole).value<bool>()) {
+    if (index.data(IsRadioRole).toBool()) {
         /// clicking on an alternative's item in tree view should select alternative
         switchRadioFlag(index);
         event->accept();
@@ -89,7 +92,7 @@ void RadioButtonTreeView::mouseReleaseEvent(QMouseEvent *event)
 void RadioButtonTreeView::keyReleaseEvent(QKeyEvent *event)
 {
     QModelIndex index = currentIndex();
-    if (index.data(IsRadioRole).value<bool>() && event->key() == Qt::Key_Space) {
+    if (index.data(IsRadioRole).toBool() && event->key() == Qt::Key_Space) {
         /// pressing space on an alternative's item in tree view should select alternative
         switchRadioFlag(index);
         event->accept();
