@@ -19,6 +19,7 @@
 
 #include <QNetworkReply>
 #include <QXmlStreamReader>
+#include <QTimer>
 
 #include <KUrl>
 #include <KDebug>
@@ -35,6 +36,7 @@ private:
 
 public:
     QSharedPointer<Zotero::API> api;
+    KUrl queuedRequestZoteroUrl;
 
     Private(QSharedPointer<Zotero::API> a, Zotero::Groups *parent)
             : p(parent), api(a) {
@@ -62,9 +64,19 @@ Groups::Groups(QSharedPointer<Zotero::API> api, QObject *parent)
         : QObject(parent), d(new Zotero::Groups::Private(api, this))
 {
     KUrl url = api->baseUrl();
-    Q_ASSERT_X(url.path().contains(QLatin1String("users/")), "Groups::Groups(API *api, QObject *parent)", "Provided base URL does not contain 'users/' as expected");
+    Q_ASSERT_X(url.path().contains(QLatin1String("users/")), "Groups::Groups(QSharedPointer<Zotero::API> api, QObject *parent)", "Provided base URL does not contain 'users/' as expected");
     url.addPath(QLatin1String("/groups"));
-    d->requestZoteroUrl(url);
+    if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+        /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+        d->queuedRequestZoteroUrl = url;
+        QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+    } else
+        d->requestZoteroUrl(url);
+}
+
+Groups::~Groups()
+{
+    delete d;
 }
 
 bool Groups::initialized() const
@@ -86,6 +98,18 @@ void Groups::finishedFetchingGroups()
 {
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
 
+    if (reply->hasRawHeader("Backoff")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Backoff").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Backoff' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    } else if (reply->hasRawHeader("Retry-After")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Retry-After").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Retry-After' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    }
+
     if (reply->error() == QNetworkReply::NoError) {
         QString nextPage;
         QXmlStreamReader xmlReader(reply);
@@ -117,7 +141,12 @@ void Groups::finishedFetchingGroups()
         }
 
         if (!nextPage.isEmpty())
-            d->requestZoteroUrl(nextPage);
+            if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+                /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+                d->queuedRequestZoteroUrl = nextPage;
+                QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+            } else
+                d->requestZoteroUrl(nextPage);
         else {
             d->busy = false;
             d->initialized = true;
@@ -130,3 +159,8 @@ void Groups::finishedFetchingGroups()
         emit finishedLoading();
     }
 }
+
+void Groups::singleShotRequestZoteroUrl() {
+    d->requestZoteroUrl(d->queuedRequestZoteroUrl);
+    d->queuedRequestZoteroUrl.clear();
+}
