@@ -123,6 +123,8 @@ public:
         qOAuth->setConsumerSecret("8bb22bb3262b5703d5b4");
         /// Set a timeout for requests (in msecs)
         qOAuth->setRequestTimeout(10000);
+
+        setupGUI();
     }
 
     ~Private() {
@@ -138,7 +140,6 @@ public:
 
         /// If no error occurred, read the received token and token secret
         if (qOAuth->error() == QOAuth::NoError) {
-            kDebug() << "Correctly retrieved authorization URL parameters";
             token = reply.value(QOAuth::tokenParameterName());
             tokenSecret = reply.value(QOAuth::tokenSecretParameterName());
 
@@ -205,7 +206,6 @@ public:
             tokenSecret = oAuthVerifierRequest.value(QOAuth::tokenSecretParameterName());
 
             if (!token.isEmpty() && !tokenSecret.isEmpty()) {
-                kDebug() << "KBibTeX is authorized successfully";
                 bool ok = false;
                 userId = oAuthVerifierRequest.value("userID").toInt(&ok);
                 if (!ok) {
@@ -230,7 +230,7 @@ public:
 OAuthWizard::OAuthWizard(QWidget *parent)
         : QWizard(parent), d(new OAuthWizard::Private(this))
 {
-    d->setupGUI();
+    /// nothing
 }
 
 OAuthWizard::~OAuthWizard()
@@ -267,6 +267,7 @@ void OAuthWizard::initializePage(int id)
         const QCursor currentCursor = cursor();
         setCursor(Qt::WaitCursor);
         d->lineEditAuthorizationUrl->setText(d->oAuthAuthorizationUrl().pathOrUrl());
+        d->lineEditAuthorizationUrl->setCursorPosition(0);
         setCursor(currentCursor);
     } else if (id == d->pageIdVerificationCode) {
         /// This page initializes itself, see VerificationCodePage::initializePage
