@@ -19,6 +19,7 @@
 
 #include <QNetworkReply>
 #include <QXmlStreamReader>
+#include <QTimer>
 
 #include <KUrl>
 #include <KDebug>
@@ -35,6 +36,7 @@ private:
 
 public:
     QSharedPointer<Zotero::API> api;
+    KUrl queuedRequestZoteroUrl;
 
     Private(QSharedPointer<Zotero::API> a, Zotero::Tags *parent)
             : p(parent), api(a) {
@@ -61,9 +63,21 @@ public:
 Tags::Tags(QSharedPointer<Zotero::API> api, QObject *parent)
         : QObject(parent), d(new Zotero::Tags::Private(api, this))
 {
+
     KUrl url = api->baseUrl();
     url.addPath(QLatin1String("/tags"));
-    d->requestZoteroUrl(url);
+
+    if (api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+        /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+        d->queuedRequestZoteroUrl = url;
+        QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+    } else
+        d->requestZoteroUrl(url);
+}
+
+Tags::~Tags()
+{
+    delete d;
 }
 
 bool Tags::initialized() const
@@ -85,6 +99,18 @@ void Tags::finishedFetchingTags()
 {
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
 
+    if (reply->hasRawHeader("Backoff")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Backoff").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Backoff' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    } else if (reply->hasRawHeader("Retry-After")) {
+        bool ok = false;
+        int time = QString::fromLatin1(reply->rawHeader("Retry-After").constData()).toInt(&ok);
+        if (!ok) time = 10; ///< parsing argument of raw header 'Retry-After' failed? 10 seconds is fallback
+        d->api->startBackoff(time);
+    }
+
     if (reply->error() == QNetworkReply::NoError) {
         QString nextPage;
         QXmlStreamReader xmlReader(reply);
@@ -115,9 +141,14 @@ void Tags::finishedFetchingTags()
                 break;
         }
 
-        if (!nextPage.isEmpty())
-            d->requestZoteroUrl(nextPage);
-        else {
+        if (!nextPage.isEmpty()) {
+            if (d->api->inBackoffMode() && d->queuedRequestZoteroUrl.isEmpty()) {
+                /// If Zotero asked to 'back off', wait until this period is over before issuing the next request
+                d->queuedRequestZoteroUrl = nextPage;
+                QTimer::singleShot((d->api->backoffSecondsLeft() + 1) * 1000, this, SLOT(singleShotRequestZoteroUrl()));
+            } else
+                d->requestZoteroUrl(nextPage);
+        } else {
             d->busy = false;
             d->initialized = true;
             emit finishedLoading();
@@ -129,3 +160,8 @@ void Tags::finishedFetchingTags()
         emit finishedLoading();
     }
 }
+
+void Tags::singleShotRequestZoteroUrl() {
+    d->requestZoteroUrl(d->queuedRequestZoteroUrl);
+    d->queuedRequestZoteroUrl.clear();
+}
