@@ -40,6 +40,9 @@ class OpenFileInfo : public QObject
     Q_OBJECT
 
 public:
+    static const int FileIdStart = 0;
+    static const int FileIdInvalid = -1;
+
     enum StatusFlag {
         Open = 0x1,
         RecentlyUsed = 0x2,
@@ -80,6 +83,8 @@ public:
     KService::Ptr defaultService();
     KService::Ptr currentService();
 
+    int fileId() const;
+
     friend class OpenFileInfoManager;
 
 signals:
